@@ -23,6 +23,10 @@ import concurrent.futures
 import logging
 
 
+class CircularDependencyError(Exception):
+    """Raised if there are circular dependencies detected."""
+
+
 class LowerDict(dict):
 
     def __getitem__(self, key):
@@ -42,6 +46,10 @@ def reasons_to_paths(reasons):
         path = [blocker]
         parent = reasons[blocker]
         while parent:
+            if parent in path:
+                raise CircularDependencyError(dict(parent=parent,
+                                                   blocker=blocker,
+                                                   path=path))
             path.append(parent)
             parent = reasons.get(parent)
         paths.add(tuple(path))
@@ -77,7 +85,13 @@ def blocking_dependencies(projects, py3_projects):
     check = []
     evaluated = set()
     for project in projects:
-        dist = distlib.locators.locate(project)
+        log.info('Checking top-level project: {0} ...'.format(project))
+        try:
+            dist = distlib.locators.locate(project)
+        except AttributeError:
+            # This is a work around. //bitbucket.org/pypa/distlib/issue/59/ .
+            log.warning('{0} found but had to be skipped.'.format(project))
+            continue
         if not dist:
             log.warning('{0} not found'.format(project))
             continue
@@ -97,7 +111,9 @@ def blocking_dependencies(projects, py3_projects):
                     # can't port.
                     del reasons[parent]
                     continue
+                log.info('Dependencies of {0}: {1}'.format(project, deps))
                 for dep in deps:
+                    log.info('Checking dependency: {0} ...'.format(dep))
                     if dep in evaluated:
                         log.info('{0} already checked'.format(dep))
                         continue
